# Copyright (c) 2007-2016 Godefroid Chapelle and ipdb development team
#
# This file is part of ipdb.
# Redistributable under the revised BSD license
# https://opensource.org/licenses/BSD-3-Clause

from ipdb.__main__ import set_trace, post_mortem, pm, run, runcall, runeval, launch_ipdb_on_exception

pm                       # please pyflakes
post_mortem              # please pyflakes
run                      # please pyflakes
runcall                  # please pyflakes
runeval                  # please pyflakes
set_trace                # please pyflakes
launch_ipdb_on_exception # please pyflakes

from ipdb.stdout import sset_trace, spost_mortem, spm, slaunch_ipdb_on_exception

spm                       # please pyflakes
spost_mortem              # please pyflakes
sset_trace                # please pyflakes
slaunch_ipdb_on_exception # please pyflakes
